@@ -16,11 +16,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Get and set Renku repository or global options."""
-from renku.command.command_builder import inject
+
 from renku.command.command_builder.command import Command
 from renku.core import errors
+from renku.core.config import get_config, get_value, remove_value, set_value
 from renku.core.constant import CONFIG_LOCAL_PATH
-from renku.core.interface.client_dispatcher import IClientDispatcher
 from renku.domain_model.enums import ConfigFilter
 
 
@@ -65,15 +65,11 @@ def update_multiple_config():
     )
 
 
-@inject.autoparams()
-def _update_config(
-    key, client_dispatcher: IClientDispatcher, *, value=None, remove=False, global_only=False, commit_message=None
-):
+def _update_config(key, *, value=None, remove=False, global_only=False, commit_message=None):
     """Add, update, or remove configuration values.
 
     Args:
         key: Config key.
-        client_dispatcher(IClientDispatcher):  Injected client dispatcher.
         value: Config value (Default value = None).
         remove: Whether to remove values (Default value = False).
         global_only: Whether to only update global config (Default value = False).
@@ -83,14 +79,13 @@ def _update_config(
     Returns:
         The modified/removed value.
     """
-    client = client_dispatcher.current_client
     section, section_key = _split_section_and_key(key)
     if remove:
-        value = client.remove_value(section, section_key, global_only=global_only)
+        value = remove_value(section, section_key, global_only=global_only)
         if value is None:
             raise errors.ParameterError('Key "{}" not found.'.format(key))
     else:
-        client.set_value(section, section_key, value, global_only=global_only)
+        set_value(section, section_key, value, global_only=global_only)
         return value
 
 
@@ -105,28 +100,25 @@ def update_config():
     )
 
 
-@inject.autoparams()
-def _read_config(key, client_dispatcher: IClientDispatcher, config_filter=ConfigFilter.ALL, as_string=True):
+def _read_config(key, config_filter=ConfigFilter.ALL, as_string=True):
     """Read configuration.
 
     Args:
         key: Config key.
-        client_dispatcher(IClientDispatcher):  Injected client dispatcher.
         config_filter: Which config files to read from (Default value = ConfigFilter.ALL).
         as_string: Whether to return a string or dictionary (Default value = True).
 
     Returns:
         String or dictionary containing configuration values.
     """
-    client = client_dispatcher.current_client
     if key:
         section, section_key = _split_section_and_key(key)
-        value = client.get_value(section, section_key, config_filter=config_filter)
+        value = get_value(section, section_key, config_filter=config_filter)
         if value is None:
-            raise errors.ParameterError('Key "{}" not found.'.format(key))
+            raise errors.ParameterError(f"Key '{key}' not found.")
         return value
 
-    return client.get_config(config_filter=config_filter, as_string=as_string)
+    return get_config(config_filter=config_filter, as_string=as_string)
 
 
 def read_config():
