@@ -25,39 +25,37 @@ from renku.command.command_builder import inject
 from renku.command.command_builder.command import Command
 from renku.core import errors
 from renku.core.dataset.datasets_provenance import DatasetsProvenance
-from renku.core.interface.client_dispatcher import IClientDispatcher
 from renku.core.interface.dataset_gateway import IDatasetGateway
+from renku.core.storage import check_external_storage, untrack_paths_from_storage
 from renku.core.util import communication
 from renku.core.util.git import get_git_user
-from renku.core.util.os import delete_dataset_file
+from renku.core.util.os import delete_dataset_file, expand_directories
+from renku.domain_model.project_context import project_context
 
 
 @inject.autoparams()
-def _remove(sources, edit_command, client_dispatcher: IClientDispatcher, dataset_gateway: IDatasetGateway):
+def _remove(sources, edit_command, dataset_gateway: IDatasetGateway):
     """Remove files and check repository for potential problems.
 
     Args:
         sources: Files to remove.
         edit_command: Command to execute for editing .gitattributes.
-        client_dispatcher(IClientDispatcher): Injected client dispatcher.
         dataset_gateway(IDatasetGateway): Injected dataset gateway.
     """
-    from renku.core.management.git import _expand_directories
-
-    client = client_dispatcher.current_client
+    repository = project_context.repository
 
     def get_relative_path(path):
-        """Format path as relative to the client path."""
-        abs_path = os.path.abspath(client.path / path)
+        """Format path as relative to the project path."""
+        abs_path = os.path.abspath(project_context.path / path)
         try:
-            return str(Path(abs_path).relative_to(client.path))
+            return str(Path(abs_path).relative_to(project_context.path))
         except ValueError:
             raise errors.ParameterError(f"File {abs_path} is not within the project.")
 
     files = {
         get_relative_path(source): get_relative_path(file_or_dir)
         for file_or_dir in sources
-        for source in _expand_directories((file_or_dir,))
+        for source in expand_directories((file_or_dir,))
     }
 
     # 1. Update dataset metadata files.
@@ -77,28 +75,26 @@ def _remove(sources, edit_command, client_dispatcher: IClientDispatcher, dataset
                 dataset = dataset.copy()
                 for key in remove:
                     dataset.unlink_file(key)
-                    delete_dataset_file(client.path / key, follow_symlinks=True)
+                    delete_dataset_file(project_context.path / key, follow_symlinks=True)
 
                 datasets_provenance = DatasetsProvenance()
-                datasets_provenance.add_or_update(dataset, creator=get_git_user(client.repository))
+                datasets_provenance.add_or_update(dataset, creator=get_git_user(repository))
             communication.update_progress(progress_text, amount=1)
     finally:
         communication.finalize_progress(progress_text)
 
     # 2. Manage .gitattributes for external storage.
-    if client.check_external_storage():
-        tracked = tuple(
-            path for path, attr in client.repository.get_attributes(*files).items() if attr.get("filter") == "lfs"
-        )
-        client.untrack_paths_from_storage(*tracked)
-        existing = client.repository.get_attributes(*tracked)
+    if check_external_storage():
+        tracked = tuple(path for path, attr in repository.get_attributes(*files).items() if attr.get("filter") == "lfs")
+        untrack_paths_from_storage(*tracked)
+        existing = repository.get_attributes(*tracked)
         if existing:
             communication.warn("There are custom .gitattributes.\n")
             if communication.confirm('Do you want to edit ".gitattributes" now?'):
-                edit_command(filename=str(client.path / ".gitattributes"))
+                edit_command(filename=str(project_context.path / ".gitattributes"))
 
     # Finally remove the files.
-    files_to_remove = set(str(client.path / f) for f in files.values())
+    files_to_remove = set(str(project_context.path / f) for f in files.values())
     final_sources = list(files_to_remove)
     if final_sources:
         run(["git", "rm", "-rf"] + final_sources, check=True)
