@@ -25,16 +25,17 @@ from typing import TYPE_CHECKING, Dict, List, Optional, Set, Union
 
 from renku.core import errors
 from renku.core.dataset.providers.api import ProviderApi, ProviderPriority
+from renku.core.storage import pull_paths_from_storage
 from renku.core.util import communication
 from renku.core.util.dataset import check_url
 from renku.core.util.git import clone_repository, get_cache_directory_for_repository
 from renku.core.util.os import get_files, is_subpath
 from renku.core.util.urls import remove_credentials
 from renku.domain_model.dataset import RemoteEntity
+from renku.domain_model.project_context import project_context
 
 if TYPE_CHECKING:
     from renku.core.dataset.providers.models import DatasetAddMetadata, ProviderParameter
-    from renku.core.management.client import LocalClient
 
 
 class GitProvider(ProviderApi):
@@ -78,7 +79,6 @@ class GitProvider(ProviderApi):
 
     @staticmethod
     def add(
-        client: "LocalClient",
         uri: str,
         destination: Path,
         *,
@@ -88,14 +88,13 @@ class GitProvider(ProviderApi):
     ) -> List["DatasetAddMetadata"]:
         """Add files from a URI to a dataset."""
         from renku.core.dataset.providers.models import DatasetAddAction, DatasetAddMetadata
-        from renku.core.management.client import LocalClient
 
         destination_exists = destination.exists()
         destination_is_dir = destination.is_dir()
 
         remote_repository = clone_repository(
             url=uri,
-            path=get_cache_directory_for_repository(client=client, url=uri),
+            path=get_cache_directory_for_repository(url=uri),
             checkout_revision=revision,
             depth=None,
             clean=True,
@@ -138,7 +137,7 @@ class GitProvider(ProviderApi):
 
         def get_metadata(src: Path, dst: Path) -> Optional["DatasetAddMetadata"]:
             path_in_src_repo = src.relative_to(remote_repository.path)  # type: ignore
-            path_in_dst_repo = dst.relative_to(client.path)
+            path_in_dst_repo = dst.relative_to(project_context.path)
 
             already_copied = path_in_dst_repo in new_files  # A path with the same destination is already copied
             new_files[path_in_dst_repo].append(path_in_src_repo)
@@ -164,7 +163,8 @@ class GitProvider(ProviderApi):
         new_files: Dict[Path, List[Path]] = defaultdict(list)
 
         paths = get_source_paths()
-        LocalClient(path=remote_repository.path).pull_paths_from_storage(*paths)
+        with project_context.with_path(remote_repository.path):
+            pull_paths_from_storage(project_context.repository, *paths)
         is_copy = should_copy(list(paths))
 
         for path in paths:
