@@ -24,22 +24,19 @@ from collections import defaultdict
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, List, Optional
 
-from renku.command.command_builder.command import inject
 from renku.command.login import read_renku_token
 from renku.core import errors
 from renku.core.dataset.datasets_provenance import DatasetsProvenance
 from renku.core.dataset.providers.api import ImporterApi, ProviderApi, ProviderPriority
-from renku.core.interface.client_dispatcher import IClientDispatcher
-from renku.core.interface.database_dispatcher import IDatabaseDispatcher
+from renku.core.storage import pull_paths_from_storage
 from renku.core.util import communication
-from renku.core.util.file_size import bytes_to_unit
 from renku.core.util.git import clone_renku_repository, get_cache_directory_for_repository, get_file_size
 from renku.core.util.metadata import is_external_file, make_project_temp_dir
 from renku.core.util.urls import remove_credentials
+from renku.domain_model.project_context import project_context
 
 if TYPE_CHECKING:
     from renku.core.dataset.providers.models import DatasetAddMetadata, ProviderDataset, ProviderParameter
-    from renku.core.management.client import LocalClient
     from renku.domain_model.dataset import Dataset
 
 
@@ -254,7 +251,7 @@ class RenkuImporter(ImporterApi):
 
         self._project_url = None
         self._remote_repository = None
-        self._remote_client = None
+        self._remote_path = None
 
     def fetch_provider_dataset(self) -> "ProviderDataset":
         """Return encapsulated dataset instance."""
@@ -262,10 +259,9 @@ class RenkuImporter(ImporterApi):
         assert self._provider_dataset is not None, "Dataset wasn't fetched."
         return self._provider_dataset
 
-    def download_files(self, client: "LocalClient", destination: Path, extract: bool) -> List["DatasetAddMetadata"]:
+    def download_files(self, destination: Path, extract: bool) -> List["DatasetAddMetadata"]:
         """Download dataset files from the remote provider."""
         from renku.core.dataset.providers.models import DatasetAddAction, DatasetAddMetadata
-        from renku.core.management.client import LocalClient
         from renku.domain_model.dataset import RemoteEntity
 
         url = remove_credentials(self.project_url)
@@ -298,15 +294,15 @@ class RenkuImporter(ImporterApi):
                 relative_path = Path(src_entity_path)
 
             dst = destination / relative_path
-            path_in_dst_repo = dst.relative_to(client.path)
+            path_in_dst_repo = dst.relative_to(project_context.path)
 
             already_copied = path_in_dst_repo in new_files  # A path with the same destination is already copied
             new_files[path_in_dst_repo].append(src_entity_path)
             if already_copied:
                 return
 
-            if is_external_file(path=src_entity_path, client_path=remote_repository.path):  # type: ignore
-                source = (remote_repository.path / src_entity_path).resolve()  # type: ignore
+            if is_external_file(path=src_entity_path, project_path=remote_repository.path):
+                source = (remote_repository.path / src_entity_path).resolve()
                 action = DatasetAddAction.SYMLINK
             else:
                 source = content_path
@@ -332,14 +328,15 @@ class RenkuImporter(ImporterApi):
         new_files: Dict[Path, List[str]] = defaultdict(list)
 
         if checksums is None:
-            LocalClient(path=remote_repository.path).pull_paths_from_storage(  # type: ignore
-                *(remote_repository.path / p for p in sources)  # type: ignore
-            )
+            with project_context.with_path(remote_repository.path):
+                pull_paths_from_storage(
+                    project_context.repository, *(remote_repository.path / p for p in sources)  # type: ignore
+                )
 
             for file in sources:
                 add_file(file, content_path=remote_repository.path / file, checksum=None)  # type: ignore
         else:  # NOTE: Renku dataset import with a tag
-            content_path_root = make_project_temp_dir(client.path)
+            content_path_root = make_project_temp_dir(project_context.path)
             content_path_root.mkdir(parents=True, exist_ok=True)
             filename = 1
 
@@ -383,19 +380,16 @@ class RenkuImporter(ImporterApi):
 
     def copy_extra_metadata(self, new_dataset: "Dataset") -> None:
         """Copy provider specific metadata once the dataset is created."""
-        from renku.core.util.dispatcher import get_client
 
         if not self.provider_dataset.images:
             return
 
-        client = get_client()
-
         for image in self.provider_dataset.images:
             if image.is_absolute:
                 continue
 
-            remote_image_path = self._remote_client.path / image.content_url
-            local_image_path = client.path / image.content_url
+            remote_image_path = self._remote_path / image.content_url
+            local_image_path = project_context.path / image.content_url
             local_image_path.parent.mkdir(exist_ok=True, parents=True)
 
             shutil.copy(remote_image_path, local_image_path)
@@ -440,16 +434,13 @@ class RenkuImporter(ImporterApi):
     @property
     def datadir_exists(self):
         """Whether the dataset data directory exists (might be missing in git if empty)."""
-        return (self._remote_client.path / self.provider_dataset.get_datadir()).exists()
+        return (self._remote_path / self.provider_dataset.get_datadir()).exists()
 
-    @inject.autoparams()
-    def _fetch_dataset(self, client_dispatcher: IClientDispatcher, database_dispatcher: IDatabaseDispatcher):
+    def _fetch_dataset(self):
         from renku.core.dataset.providers.models import ProviderDataset, ProviderDatasetFile
-        from renku.core.management.client import LocalClient
         from renku.domain_model.dataset import Url
 
-        repository = None
-        client = client_dispatcher.current_client
+        remote_repository = None
 
         parsed_uri = urllib.parse.urlparse(self.uri)
 
@@ -458,9 +449,9 @@ class RenkuImporter(ImporterApi):
         communication.echo(msg="Cloning remote repository...")
         for url in urls:
             try:
-                repository = clone_renku_repository(
+                remote_repository = clone_renku_repository(
                     url=url,
-                    path=get_cache_directory_for_repository(client=client, url=url),
+                    path=get_cache_directory_for_repository(url=url),
                     gitlab_token=self._gitlab_token,
                     deployment_hostname=parsed_uri.netloc,
                     depth=None,
@@ -473,16 +464,14 @@ class RenkuImporter(ImporterApi):
                 self._project_url = url
                 break
 
-        if self._project_url is None or repository is None:
+        if self._project_url is None or remote_repository is None:
             raise errors.ParameterError("Cannot clone remote projects:\n\t" + "\n\t".join(urls), param_hint=self.uri)
 
-        self._remote_client = LocalClient(path=repository.path)
-        client_dispatcher.push_created_client_to_stack(self._remote_client)
-        database_dispatcher.push_database_to_stack(self._remote_client.database_path)
+        with project_context.with_path(remote_repository.path):
+            self._remote_path = project_context.path
 
-        try:
             self._migrate_project()
-            self._remote_repository = repository
+            self._remote_repository = remote_repository
 
             datasets_provenance = DatasetsProvenance()
 
@@ -508,9 +497,6 @@ class RenkuImporter(ImporterApi):
             provider_dataset.version = self._tag
             # NOTE: Store the tag so that it can be checked later to see if a tag was specified for import
             provider_dataset.tag = tag
-        finally:
-            database_dispatcher.pop_database()
-            client_dispatcher.pop_client()
 
         provider_dataset.derived_from = None
         provider_dataset.same_as = Url(url_id=remove_credentials(self.latest_uri))
@@ -521,7 +507,7 @@ class RenkuImporter(ImporterApi):
                 checksum=file.entity.checksum,
                 filename=Path(file.entity.path).name,
                 filetype=Path(file.entity.path).suffix.replace(".", ""),
-                size_in_mb=bytes_to_unit(get_file_size(self._remote_client.path, file.entity.path), "mi"),
+                filesize=get_file_size(self._remote_path, file.entity.path),
                 source=file.source,
             )
             for file in dataset.files
@@ -531,8 +517,8 @@ class RenkuImporter(ImporterApi):
 
     @staticmethod
     def _migrate_project():
-        from renku.core.management.migrate import is_project_unsupported, migrate  # Slow import
-        from renku.core.migration.utils import MigrationType
+        from renku.core.migration.migrate import is_project_unsupported, migrate_project  # Slow import
+        from renku.core.migration.models.migration import MigrationType
 
         if is_project_unsupported():
             return
@@ -540,7 +526,7 @@ class RenkuImporter(ImporterApi):
         try:
             communication.disable()
             # NOTE: We are not interested in migrating workflows when importing datasets
-            migrate(
+            migrate_project(
                 skip_template_update=True, skip_docker_update=True, migration_type=~MigrationType.WORKFLOWS, strict=True
             )
         finally:
