@@ -30,8 +30,8 @@ from renku.core.dataset.providers.api import ExporterApi, ProviderApi, ProviderP
 from renku.core.dataset.providers.repository import RepositoryImporter, make_request
 from renku.core.util import communication
 from renku.core.util.doi import is_doi
-from renku.core.util.file_size import bytes_to_unit
 from renku.core.util.urls import remove_credentials
+from renku.domain_model.project_context import project_context
 
 if TYPE_CHECKING:
     from renku.core.dataset.providers.models import ProviderDataset, ProviderParameter
@@ -219,7 +219,7 @@ class ZenodoImporter(RepositoryImporter):
                 source=file.remote_url.geturl(),
                 filename=Path(file.filename).name,
                 checksum=file.checksum,
-                size_in_mb=bytes_to_unit(file.filesize, "mi"),
+                filesize=file.filesize,
                 filetype=file.type,
                 path="",
             )
@@ -367,7 +367,7 @@ class ZenodoExporter(ExporterApi):
         jsonld["upload_type"] = "dataset"
         return jsonld
 
-    def export(self, client=None, **kwargs):
+    def export(self, **kwargs):
         """Execute entire export process."""
         # Step 1. Create new deposition
         deposition = ZenodoDeposition(exporter=self)
@@ -378,7 +378,9 @@ class ZenodoExporter(ExporterApi):
         # Step 3. Upload all files to created deposition
         with communication.progress("Uploading files ...", total=len(self.dataset.files)) as progressbar:
             for file in self.dataset.files:
-                filepath = client.repository.copy_content_to_file(path=file.entity.path, checksum=file.entity.checksum)
+                filepath = project_context.repository.copy_content_to_file(
+                    path=file.entity.path, checksum=file.entity.checksum
+                )
                 deposition.upload_file(filepath, path_in_repo=file.entity.path)
                 progressbar.update()
 
