@@ -17,15 +17,18 @@
 # limitations under the License.
 """Git utility functions."""
 
+import contextlib
 import os
 import pathlib
 import re
 import shutil
+import sys
+import time
 import urllib
 from functools import reduce
 from pathlib import Path
 from subprocess import PIPE, SubprocessError, run
-from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union, cast
+from typing import TYPE_CHECKING, Dict, List, Optional, Set, Tuple, Union, cast
 from uuid import uuid4
 
 from renku.core import errors
@@ -37,6 +40,9 @@ if TYPE_CHECKING:
     from renku.infrastructure.repository import Commit, Remote, Repository
 
 
+COMMIT_DIFF_STRATEGY = "DIFF"
+STARTED_AT = int(time.time() * 1e3)
+
 BRANCH_NAME_LIMIT = 250
 CLI_GITLAB_ENDPOINT = "repos"
 PROTECTED_BRANCH_PREFIX = "renku/autobranch"
@@ -96,18 +102,18 @@ def is_valid_git_repository(repository: Optional["Repository"]) -> bool:
     return repository is not None and repository.head.is_valid()
 
 
-def get_hook_path(repository, name: str) -> Path:
+def get_hook_path(path: Path, name: str) -> Path:
     """Return path to the given named hook in the given repository.
 
     Args:
-        repository: The current Git repository.
+        path(Path): The current Git repository's path.
         name(str): The name of the hook.
 
     Returns:
         Path: Path to the hook.
 
     """
-    return repository.path / ".git" / "hooks" / name
+    return path / ".git" / "hooks" / name
 
 
 def get_oauth_url(url, gitlab_token):
@@ -129,11 +135,10 @@ def get_oauth_url(url, gitlab_token):
     return parsed_url._replace(netloc=netloc).geturl()
 
 
-def get_cache_directory_for_repository(client, url) -> Path:
-    """Return a path to client's cache directory.
+def get_cache_directory_for_repository(url) -> Path:
+    """Return a path to project's cache directory.
 
     Args:
-        client: ``LocalCLient``.
         url: The repository URL.
 
     Returns:
@@ -141,8 +146,9 @@ def get_cache_directory_for_repository(client, url) -> Path:
 
     """
     from renku.core.constant import CACHE
+    from renku.domain_model.project_context import project_context
 
-    return client.renku_path / CACHE / get_full_repository_path(url)
+    return project_context.metadata_path / CACHE / get_full_repository_path(url)
 
 
 def parse_git_url(url: Optional[str]) -> "GitURL":
@@ -416,14 +422,33 @@ def get_entity_from_revision(
     return entity
 
 
-def default_path(path="."):
-    """Return default repository path."""
-    from renku.command.git import get_git_home
+def get_git_path(path: Union[Path, str] = ".") -> Path:
+    """Return the repository path."""
+    # TODO: Implement this using ``git rev-parse --git-dir``
+    try:
+        path = get_git_repository(path=path).path
+    except ValueError:
+        path = Path(path)
+
+    return path.resolve()
+
+
+def get_git_repository(path: Union[Path, str] = ".") -> "Repository":
+    """Get Git repository from the current path or any of its parents.
+
+    Args:
+        path: Path to start from (Default value = ".").
+    Raises:
+        ValueError: If not inside a git repository.
+    Returns:
+        Git repository
+    """
+    from renku.infrastructure.repository import Repository
 
     try:
-        return get_git_home(path=path)
-    except ValueError:
-        return path
+        return Repository(path, search_parent_directories=True)
+    except errors.GitError:
+        raise ValueError(f"Cannot find a git repository at '{path}'")
 
 
 def commit_changes(*paths: Union[Path, str], repository: "Repository", message=None) -> List[str]:
@@ -688,7 +713,7 @@ def clone_repository(
     Returns:
         The cloned repository.
     """
-    from renku.core.management.githooks import install
+    from renku.core.githooks import install
     from renku.infrastructure.repository import Repository
 
     def handle_git_exception():
@@ -715,7 +740,7 @@ def clone_repository(
         except PermissionError as e:
             raise errors.InvalidFileOperation(f"Cannot delete files in {path}: Permission denied") from e
 
-    def check_and_reuse_existing_repository() -> Optional[Repository]:
+    def check_and_reuse_existing_repository() -> Optional["Repository"]:
         if path is None or not cast(Path, path).exists():
             return None
 
@@ -797,7 +822,7 @@ def clone_repository(
                 config_writer.set_value(section, option, value)
 
     if install_githooks:
-        install(force=True, repository=repository)
+        install(force=True, path=repository.path)
 
     if install_lfs:
         repository.lfs.install(skip_smudge=skip_smudge)
@@ -831,7 +856,7 @@ def get_git_progress_instance():
     return GitProgress()
 
 
-def get_file_size(repository_path: Path, path: str) -> Optional[float]:
+def get_file_size(repository_path: Path, path: str) -> Optional[int]:
     """Return file size for a file inside a git repository."""
     # NOTE: First try to get file size from Git LFS
     try:
@@ -865,11 +890,11 @@ def get_file_size(repository_path: Path, path: str) -> Optional[float]:
             multiplier = conversions.get(unit, None)
             if multiplier is None:
                 continue
-            return size * multiplier
+            return int(size * multiplier)
 
     # Return size of the file on disk
     full_path = repository_path / path
-    return float(os.path.getsize(full_path)) if full_path.exists() else None
+    return os.path.getsize(full_path) if full_path.exists() else None
 
 
 def shorten_message(message: str, line_length: int = 100, body_length: int = 65000) -> str:
@@ -914,3 +939,182 @@ def shorten_message(message: str, line_length: int = 100, body_length: int = 650
         ("", 0),
     )[0]
     return wrapped_message[1:]
+
+
+def get_in_submodules(
+    repository: "Repository", commit: "Commit", path: Union[Path, str]
+) -> Tuple["Repository", "Commit", Path]:
+    """Resolve filename in submodules."""
+    original_path = repository.path / path
+    in_vendor = str(path).startswith(".renku/vendors")
+
+    if original_path.is_symlink() or in_vendor:
+        resolved_path = original_path.resolve()
+
+        for submodule in repository.submodules:  # type: ignore
+            if not (submodule.path / ".git").exists():
+                continue
+
+            try:
+                path_within_submodule = resolved_path.relative_to(submodule.path)
+                commit = submodule.get_previous_commit(path=path_within_submodule, revision=commit.hexsha)
+            except (ValueError, errors.GitCommitNotFoundError):
+                pass
+            else:
+                return submodule, commit, path_within_submodule
+
+    return repository, commit, Path(path)
+
+
+def get_dirty_paths(repository: "Repository") -> Set[str]:
+    """Get paths of dirty files in the repository."""
+    modified_files = [item.b_path for item in repository.unstaged_changes if item.b_path]
+    staged_files = [d.a_path for d in repository.staged_changes] if repository.head.is_valid() else []
+
+    return {os.path.join(repository.path, p) for p in repository.untracked_files + modified_files + staged_files}
+
+
+@contextlib.contextmanager
+def with_commit(
+    *,
+    repository: "Repository",
+    transaction_id: str,
+    commit_only=None,
+    commit_empty=True,
+    raise_if_empty=False,
+    commit_message=None,
+    abbreviate_message=True,
+    skip_dirty_checks=False,
+):
+    """Automatic commit."""
+    diff_before = prepare_commit(repository=repository, commit_only=commit_only, skip_dirty_checks=skip_dirty_checks)
+
+    yield
+
+    finalize_commit(
+        diff_before=diff_before,
+        repository=repository,
+        transaction_id=transaction_id,
+        commit_only=commit_only,
+        commit_empty=commit_empty,
+        raise_if_empty=raise_if_empty,
+        commit_message=commit_message,
+        abbreviate_message=abbreviate_message,
+    )
+
+
+def prepare_commit(*, repository: "Repository", commit_only=None, skip_dirty_checks=False, skip_staging: bool = False):
+    """Gather information about repo needed for committing later on."""
+
+    def ensure_not_untracked(path):
+        """Ensure that path is not part of git untracked files."""
+        for file_path in repository.untracked_files:
+            is_parent = (repository.path / file_path).parent == (repository.path / path)
+            is_equal = str(path) == file_path
+
+            if is_parent or is_equal:
+                raise errors.DirtyRenkuDirectory(repository)
+
+    def ensure_not_staged(path):
+        """Ensure that path is not part of git staged files."""
+        path = str(path)
+        for file_path in repository.staged_changes:
+            is_parent = str(file_path.a_path).startswith(path)
+            is_equal = path == file_path.a_path
+
+            if is_parent or is_equal:
+                raise errors.DirtyRenkuDirectory(repository)
+
+    if skip_staging:
+        if not isinstance(commit_only, list) or len(commit_only) == 0:
+            raise errors.OperationError("Cannot use ``skip_staging`` without specifying files to commit.")
+
+    diff_before = set()
+
+    if commit_only == COMMIT_DIFF_STRATEGY:
+        if len(repository.staged_changes) > 0 or len(repository.unstaged_changes) > 0:
+            repository.reset()
+
+        # Exclude files created by pipes.
+        diff_before = {
+            file for file in repository.untracked_files if STARTED_AT - int(Path(file).stat().st_ctime * 1e3) >= 1e3
+        }
+
+    if isinstance(commit_only, list) and not skip_dirty_checks:
+        for path in commit_only:
+            ensure_not_untracked(path)
+            ensure_not_staged(path)
+
+    return diff_before
+
+
+def finalize_commit(
+    *,
+    diff_before,
+    repository: "Repository",
+    transaction_id: str,
+    commit_only=None,
+    commit_empty=True,
+    raise_if_empty=False,
+    commit_message=None,
+    abbreviate_message=True,
+    skip_staging: bool = False,
+):
+    """Commit modified/added paths."""
+    from renku.core.util.urls import remove_credentials
+    from renku.infrastructure.repository import Actor
+    from renku.version import __version__, version_url
+
+    committer = Actor(name=f"renku {__version__}", email=version_url)
+
+    change_types = {item.a_path: item.change_type for item in repository.unstaged_changes}
+
+    if commit_only == COMMIT_DIFF_STRATEGY:
+        # Get diff generated in command.
+        staged_after = set(change_types.keys())
+
+        modified_after_change_types = {item.a_path: item.change_type for item in repository.staged_changes}
+
+        modified_after = set(modified_after_change_types.keys())
+
+        change_types.update(modified_after_change_types)
+
+        diff_after = set(repository.untracked_files).union(staged_after).union(modified_after)
+
+        # Remove files not touched in command.
+        commit_only = list(diff_after - diff_before)
+
+    if isinstance(commit_only, list):
+        for path_ in commit_only:
+            p = repository.path / path_
+            if p.exists() or change_types.get(str(path_)) == "D":
+                repository.add(path_)
+
+    if not commit_only:
+        repository.add(all=True)
+
+    try:
+        diffs = [d.a_path for d in repository.staged_changes]
+    except errors.GitError:
+        diffs = []
+
+    if not commit_empty and not diffs:
+        if raise_if_empty:
+            raise errors.NothingToCommit()
+        return
+
+    if commit_message and not isinstance(commit_message, str):
+        raise errors.CommitMessageEmpty()
+
+    elif not commit_message:
+        argv = [os.path.basename(sys.argv[0])] + [remove_credentials(arg) for arg in sys.argv[1:]]
+
+        commit_message = " ".join(argv)
+
+    if abbreviate_message:
+        commit_message = shorten_message(commit_message)
+
+    # NOTE: Only commit specified paths when skipping staging area
+    paths = commit_only if skip_staging else []
+    # Ignore pre-commit hooks since we have already done everything.
+    repository.commit(commit_message + transaction_id, committer=committer, no_verify=True, paths=paths)
