@@ -17,6 +17,7 @@
 # limitations under the License.
 """Helpers functions for metadata management/parsing."""
 
+import fnmatch
 import os
 import re
 import tempfile
@@ -27,9 +28,9 @@ from typing import TYPE_CHECKING, List, Optional, Tuple, Union
 from packaging.version import Version
 
 from renku.core import errors
-from renku.core.constant import RENKU_HOME, RENKU_TMP
+from renku.core.config import get_value, set_value
+from renku.core.constant import RENKU_HOME, RENKU_PROTECTED_PATHS, RENKU_TMP
 from renku.core.util import communication
-from renku.core.util.dispatcher import get_client
 from renku.core.util.os import is_subpath
 
 if TYPE_CHECKING:
@@ -90,27 +91,23 @@ def construct_creator(creator: Union[dict, str], ignore_email) -> Tuple[Optional
     return person, no_email_warning
 
 
-def is_external_file(path: Union[Path, str], client_path: Path):
+def is_external_file(path: Union[Path, str], project_path: Path):
     """Checks if a path is an external file."""
-    from renku.core.constant import RENKU_HOME
-    from renku.core.dataset.constant import POINTERS
+    from renku.core.constant import POINTERS, RENKU_HOME
 
-    path = client_path / path
-    if not path.is_symlink() or not is_subpath(path=path, base=client_path):
+    path = project_path / path
+    if not path.is_symlink() or not is_subpath(path=path, base=project_path):
         return False
 
     pointer = os.readlink(path)
     return str(os.path.join(RENKU_HOME, POINTERS)) in pointer
 
 
-def get_renku_version(client) -> Optional[str]:
-    """Return project's Renku version from its Dockerfile."""
-    return read_renku_version_from_dockerfile(client.docker_path)
-
-
-def read_renku_version_from_dockerfile(path: Union[Path, str]) -> Optional[str]:
+def read_renku_version_from_dockerfile(path: Optional[Union[Path, str]] = None) -> Optional[str]:
     """Read RENKU_VERSION from the content of path if a valid version is available."""
-    path = Path(path)
+    from renku.domain_model.project_context import project_context
+
+    path = Path(path) if path else project_context.docker_path
     if not path.exists():
         return None
 
@@ -125,9 +122,9 @@ def read_renku_version_from_dockerfile(path: Union[Path, str]) -> Optional[str]:
         return None
 
 
-def make_project_temp_dir(client_path: Path) -> Path:
+def make_project_temp_dir(project_path: Path) -> Path:
     """Create a temporary directory inside project's temp path."""
-    base = client_path / RENKU_HOME / RENKU_TMP
+    base = project_path / RENKU_HOME / RENKU_TMP
     base.mkdir(parents=True, exist_ok=True)
 
     return Path(tempfile.mkdtemp(dir=base))
@@ -136,13 +133,13 @@ def make_project_temp_dir(client_path: Path) -> Path:
 def store_credentials(section: str, key: str, value: str) -> None:
     """Write provider's credentials."""
     section, key = _get_section_and_key(section=section, key=key)
-    get_client().set_value(section=section, key=key, value=value, global_only=True)
+    set_value(section=section, key=key, value=value, global_only=True)
 
 
 def read_credentials(section: str, key: str) -> Optional[str]:
     """Read provider's credentials."""
     section, key = _get_section_and_key(section=section, key=key)
-    return get_client().get_value(section=section, key=key)
+    return get_value(section=section, key=key)
 
 
 def get_canonical_key(key: str) -> str:
@@ -173,3 +170,19 @@ def prompt_for_credentials(provider_credentials: "ProviderCredentials") -> None:
     if prompt_to_store:
         if communication.confirm("Store credentials?", default=True):
             provider_credentials.store()
+
+
+def is_protected_path(path: Path) -> bool:
+    """Checks if a path is a protected path."""
+    from renku.domain_model.project_context import project_context
+
+    try:
+        path_in_repo = str(path.relative_to(project_context.path))
+    except ValueError:
+        return False
+
+    for protected_path in RENKU_PROTECTED_PATHS:
+        if fnmatch.fnmatch(path_in_repo, protected_path):
+            return True
+
+    return False
