@@ -27,9 +27,9 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, cast
 from renku.command.command_builder import inject
 from renku.core import errors
 from renku.core.interface.activity_gateway import IActivityGateway
-from renku.core.interface.client_dispatcher import IClientDispatcher
 from renku.core.interface.plan_gateway import IPlanGateway
 from renku.core.plugin.provider import execute
+from renku.core.storage import check_external_storage, pull_paths_from_storage
 from renku.core.util import communication
 from renku.core.util.datetime8601 import local_now
 from renku.core.util.os import safe_read_yaml
@@ -37,6 +37,7 @@ from renku.core.workflow.concrete_execution_graph import ExecutionGraph
 from renku.core.workflow.plan import is_plan_removed
 from renku.core.workflow.plan_factory import delete_indirect_files_list
 from renku.core.workflow.value_resolution import ValueResolver
+from renku.domain_model.project_context import project_context
 from renku.domain_model.provenance.activity import Activity, ActivityCollection
 from renku.domain_model.workflow.plan import AbstractPlan
 
@@ -44,10 +45,9 @@ if TYPE_CHECKING:
     from networkx import DiGraph
 
 
-@inject.params(client_dispatcher=IClientDispatcher, activity_gateway=IActivityGateway, plan_gateway=IPlanGateway)
+@inject.params(activity_gateway=IActivityGateway, plan_gateway=IPlanGateway)
 def execute_workflow_graph(
     dag: "DiGraph",
-    client_dispatcher: IClientDispatcher,
     activity_gateway: IActivityGateway,
     plan_gateway: IPlanGateway,
     provider="cwltool",
@@ -57,18 +57,15 @@ def execute_workflow_graph(
 
     Args:
         dag(DiGraph): The workflow graph to execute.
-        client_dispatcher(IClientDispatcher): The injected client dispatcher.
         activity_gateway(IActivityGateway): The injected activity gateway.
         plan_gateway(IPlanGateway): The injected plan gateway.
         provider: Provider to run the workflow with (Default value = "cwltool").
         config: Path to config for the workflow provider (Default value = None).
     """
-    client = client_dispatcher.current_client
-
     inputs = {i.actual_value for p in dag.nodes for i in p.inputs}
     # NOTE: Pull inputs from Git LFS or other storage backends
-    if client.check_external_storage():
-        client.pull_paths_from_storage(*inputs)
+    if check_external_storage():
+        pull_paths_from_storage(project_context.repository, *inputs)
 
     # check whether the none generated inputs of workflows are available
     outputs = {o.actual_value for p in dag.nodes for o in p.outputs}
@@ -76,14 +73,14 @@ def execute_workflow_graph(
         if not Path(i).exists():
             raise errors.ParameterError(f"Input '{i}' for the workflow does not exists!")
 
-    delete_indirect_files_list(client.path)
+    delete_indirect_files_list(project_context.path)
 
     if config:
         config = safe_read_yaml(config)
 
     started_at_time = local_now()
 
-    execute(dag=dag, basedir=client.path, provider=provider, config=config)
+    execute(dag=dag, basedir=project_context.path, provider=provider, config=config)
 
     ended_at_time = local_now()
 
@@ -92,7 +89,12 @@ def execute_workflow_graph(
     for plan in dag.nodes:
         # NOTE: Update plans are copies of Plan objects. We need to use the original Plan objects to avoid duplicates.
         original_plan = plan_gateway.get_by_id(plan.id)
-        activity = Activity.from_plan(plan=plan, started_at_time=started_at_time, ended_at_time=ended_at_time)
+        activity = Activity.from_plan(
+            plan=plan,
+            repository=project_context.repository,
+            started_at_time=started_at_time,
+            ended_at_time=ended_at_time,
+        )
         activity.association.plan = original_plan
         activity_gateway.add(activity)
         activities.append(activity)
