@@ -30,16 +30,15 @@ import marshmallow
 
 from renku.core import errors
 from renku.core.util.datetime8601 import fix_datetime, local_now, parse_date
-from renku.core.util.dispatcher import get_client
 from renku.core.util.git import get_entity_from_revision
 from renku.core.util.metadata import is_external_file
 from renku.core.util.urls import get_path, get_slug
 from renku.core.util.util import NO_VALUE
+from renku.domain_model.project_context import project_context
 from renku.infrastructure.immutable import Immutable, Slots
 from renku.infrastructure.persistent import Persistent
 
 if TYPE_CHECKING:
-    from renku.core.management.client import LocalClient
     from renku.domain_model.entity import Entity
     from renku.domain_model.provenance.agent import Person
     from renku.domain_model.provenance.annotation import Annotation
@@ -260,21 +259,19 @@ class DatasetFile(Slots):
         self.source: Optional[str] = str(source)
 
     @classmethod
-    def from_path(
-        cls, client, path: Union[str, Path], source=None, based_on: Optional[RemoteEntity] = None
-    ) -> "DatasetFile":
+    def from_path(cls, path: Union[str, Path], source=None, based_on: Optional[RemoteEntity] = None) -> "DatasetFile":
         """Return an instance from a path."""
         from renku.domain_model.entity import NON_EXISTING_ENTITY_CHECKSUM, Entity
 
         # NOTE: Data is added from an external storage and isn't pulled yet
-        if based_on and not (client.path / path).exists():
+        if based_on and not (project_context.path / path).exists():
             checksum = based_on.checksum if based_on.checksum else NON_EXISTING_ENTITY_CHECKSUM
             id = Entity.generate_id(checksum=checksum, path=path)
             entity = Entity(id=id, checksum=checksum, path=path)
         else:
-            entity = get_entity_from_revision(repository=client.repository, path=path, bypass_cache=True)
+            entity = get_entity_from_revision(repository=project_context.repository, path=path, bypass_cache=True)
 
-        is_external = is_external_file(path=path, client_path=client.path)
+        is_external = is_external_file(path=path, project_path=project_context.path)
         return cls(entity=entity, is_external=is_external, source=source, based_on=based_on)
 
     @staticmethod
@@ -438,13 +435,12 @@ class Dataset(Persistent):
         """Comma-separated list of keywords associated with dataset."""
         return ", ".join(self.keywords)
 
-    def get_datadir(self, client: Optional["LocalClient"] = None) -> Path:
+    def get_datadir(self) -> Path:
         """Return dataset's data directory."""
         if self.datadir:
             return Path(self.datadir)
 
-        client = client or get_client()
-        return Path(os.path.join(client.data_dir, self.name))
+        return Path(os.path.join(project_context.datadir, self.name))
 
     def __repr__(self) -> str:
         return f"<Dataset {self.identifier} {self.name}>"
@@ -660,7 +656,8 @@ class DatasetDetailsJson(marshmallow.Schema):
 
     data_directory = marshmallow.fields.Method("get_datadir")
 
-    def get_datadir(self, obj):
+    @staticmethod
+    def get_datadir(obj):
         """Get data directory."""
         if isinstance(obj, dict):
             return str(obj.get("datadir_path", obj.get("datadir", "")))
@@ -699,12 +696,14 @@ class ImageObjectRequestJson(marshmallow.Schema):
     file_id = marshmallow.fields.String()
     content_url = marshmallow.fields.String()
     position = marshmallow.fields.Integer()
-    mirror_locally = marshmallow.fields.Bool(default=False)
+    mirror_locally = marshmallow.fields.Bool(dump_default=False)
 
 
-def get_file_path_in_dataset(client, dataset: Dataset, dataset_file: DatasetFile) -> Path:
+def get_file_path_in_dataset(dataset: Dataset, dataset_file: DatasetFile) -> Path:
     """Return path of a file relative to dataset's data dir."""
     try:
-        return (client.path / dataset_file.entity.path).relative_to(client.path / dataset.get_datadir(client))
+        return (project_context.path / dataset_file.entity.path).relative_to(
+            project_context.path / dataset.get_datadir()
+        )
     except ValueError:  # NOTE: File is not in the dataset's data dir
         return Path(dataset_file.entity.path)
