@@ -19,6 +19,7 @@
 
 import configparser
 import hashlib
+import itertools
 import math
 import os
 import subprocess
@@ -182,6 +183,11 @@ class BaseRepository:
             raise errors.ParameterError("Repository not set.")
         return [str(e[0]) for e in self._repository.index.entries]
 
+    @property
+    def all_files(self) -> List[str]:
+        """Return absolute paths of all files in the index and untracked files."""
+        return [os.path.join(self.path, path) for path in itertools.chain(self.files, self.untracked_files)]
+
     @property
     def lfs(self) -> "LFS":
         """Return a Git LFS manager."""
@@ -1597,6 +1603,13 @@ class RemoteManager:
                 status=e.status,
             ) from e
 
+    def get(self, remote: str) -> Optional[Remote]:
+        """Return the given remote if it exists."""
+        try:
+            return self[remote]
+        except errors.GitRemoteNotFoundError:
+            return None
+
 
 class Tag(Reference):
     """A git tag."""
