@@ -79,6 +79,13 @@ deleted/lost.
 
 .. note:: This command was introduced in renku-python version 1.0.0. Commands
    executed with previous versions of renku can't be rolled back to.
+
+.. cheatsheet::
+   :group: Undo Renku Command
+   :command: $ renku rollback
+   :description: Rollback project to a previous point in time.
+   :target: rp,ui
+
 """
 
 import click
