@@ -23,7 +23,7 @@ from typing import Dict
 from marshmallow import EXCLUDE
 
 from renku.command.init import create_from_template_local_command
-from renku.core.util.contexts import click_context
+from renku.core.util.contexts import renku_project_context
 from renku.domain_model.template import TEMPLATE_MANIFEST, TemplatesManifest
 from renku.infrastructure.repository import Repository
 from renku.ui.service.config import MESSAGE_PREFIX
@@ -147,7 +147,7 @@ class TemplatesCreateProjectCtrl(ServiceCtrl, RenkuOperationMixin):
 
         source_path = template_project.abs_path / self.ctx["identifier"]
 
-        with click_context(new_project_path, "create_from_template"):
+        with renku_project_context(new_project_path):
             create_from_template_local_command().build().execute(
                 source_path,
                 name=self.ctx["project_name"],
